# SPDX-License-Identifier: AGPL-3.0-or-later
"""Generate and display QR codes"""

from flask_babel import gettext
import re
import logging
import qrcode
import base64
import io

logger = logging.getLogger(__name__)

name = gettext('Generate and display QR codes')
description = gettext('As soon as a word like "QR" is used in search query, a QR code is generated and shown as suggestion.')
default_on = True
preference_section = 'general'
query_keywords = ['qr', 'qrcode']
query_examples = 'qr The quick brown fox jumps over the lazy dog'

qr_regex = re.compile('(qr|qrcode)\\s+(.*)', re.IGNORECASE)

class QRCodeGenerator:
    
    def __init__(self, request, search):
        self.request = request
        self.search = search
        
    def process(self):
        regex_check = qr_regex.match(self.search.search_query.query)
        if regex_check:
            function, term = regex_check.groups()
            if not term.strip():
                # end if the string is empty
                return
            
            buffered = io.BytesIO()
            img = qrcode.make(term)
            img.save(buffered, format="PNG")
            answer = 'data:image/png;base64,{}'.format(base64.b64encode(buffered.getvalue()).decode("utf-8"))
            
            # to ensure, that there is no questionable ddg answer.
            self.search.result_container.answers.clear()
            self.search.result_container.infoboxes.append({
                'infobox': 'Barcode',
                'img_src': answer,
                'content': term
            })

def post_search(request, search):  # pylint: disable=unused-argument
    """Filter searx results."""
    
    # only on first page
    if search.search_query.pageno > 1:
        return True
    
    qc = QRCodeGenerator(request, search)
    qc.process()
    return True
